criticalStorage property
Storage for log messages when in critical mode.
This is initialized when entering critical mode and cleared when exiting.
Implementation
static CriticalStorage? criticalStorage;
Storage for log messages when in critical mode.
This is initialized when entering critical mode and cleared when exiting.
static CriticalStorage? criticalStorage;